Struct Manager

pub struct Manager<const ROWS: usize, const COLS: usize, const CODE_SIZE: usize> { /* private fields */ }

Implementations

Source

impl<const ROWS: usize, const COLS: usize, const LAYOUT_MAX: usize> Manager<ROWS, COLS, LAYOUT_MAX>

pub fn load( &mut self, iter: impl IntoIterator<Item = u16>, ) -> Result<(), LoadError>

Load mapping config into Manager. The format of mapping is as follows:

protocol version layer count row_count (high byte), column_count (low byte) should match ROWS and COLS layer positions, layers. Layer positions mark the index in codes where the layers start. Layers are dense if every entry has a value; size == ROWS * COLS Layers are sparse if size < ROWS * COLS in which case it is a list of ordered tuples where the first byte is the row, second is the column and the next word is the value

pub fn find_code(&self, row: usize, column: usize) -> Option<KeyPlusMod>

pub fn get_macro(&self, id: u16) -> Macro

pub fn get_layer(&self, layer_num: u16) -> Option<Layer<'_, ROWS, COLS>>

pub fn macro_stack(&self) -> usize

pub fn set_layout(&mut self, n: u16)

pub fn push_layer(&mut self, n: u16) -> bool

pub fn pop_layer(&mut self, n: u16) -> bool